@@ -306,7 +306,7 @@ private:
     {
         size_t offset = fragment_size_;
         offset *= fragment_index;
-        offset = (offset + 3) & ~3;
+        offset = (offset + 3u) & ~3u;
         return reinterpret_cast<uint32_t*>(&serializedPayload.data[offset]);
     }
 
